#define MROP Mor
#include "mfbmap.h"
#include "../../../../mfb/mfbblt.c"
